/*
  Fabric texture macros to use with ArahWeave fabric simulations
  
  Applications:

  + use POV-Ray pigments to substitute fabric yarn colors, randomly 
    or from an array.
  + use different POV-Ray finishes for each yarn, randomly or from 
    an array.
  
  --
  Jaime Vives Piqueres, Nov.2006
*/

// yarn normal
#local n_yarn=
normal{
 bump_map{
  png fabric_bmp 
  bump_size fabric_bump_size 
 }
}

// radom finish macro
#macro rand_finish(rf)
 #local r_f=seed(1000)*rf;
 finish{
  #if (rf>rand(r_f))
   specular rand(r_f)
  #end
  #if (rf>rand(r_f))
   metallic
  #end
 }
#end

// yarn texture macro
#macro t_yarn(map_ind)
texture{
 pigment{
 #if (fabric_solid_colors)
  #if (fabric_random_colors)
   rgb <rand(r_fabric_colors),rand(r_fabric_colors),rand(r_fabric_colors)>
  #else
   rgb fabric_colors[map_ind]
  #end
 #else
  image_map{png fabric_img interpolate 2}
 #end
 }
 #if (fabric_random_finish)
  rand_finish(rand(r_fabric_finish))
 #else
  finish{fabric_finish[map_ind]}
 #end
 normal{n_yarn}
}
#end

// mix the yarns on the final fabric
#local i=0;
#declare t_fabric=
texture{
 material_map{
  png fabric_map interpolate 0
  #while (i<fabric_map_indexes)
   t_yarn(i)
   #local i=i+1;
  #end
 }
 scale fabric_scale
 rotate -90*z
}
