// Persistence Of Vision Ray Tracer Scene Description File
// -------------------------------------------------------
// File: @(#)drap.pov
// Description: drap cloth simulation based on attach.pov
// modified by Jaime Vives Piqueres to use as demo for the fabrics include
#version unofficial megapov 1.2;

// random seeds
#declare r_stand=seed(461); // stand spheres placement (for the wrinkles)
#declare st     =seed(296); // for random initial deformation

// function to deform the initial cloth points
#declare f_marblep=
function{
 pattern{
  marble
  warp{turbulence 1 lambda 0}
  scale <1,4,1>
  rotate 360*rand(st)
 }
}

// Write the initial .cth file
	#local Precision = 2;
	#macro WriteClothFile(nomfile, n1, n2, nlng, ks, ht)
		#debug "\nWriting new .cth file\n"
		#fopen file nomfile write
		#write(file, n1, ",", n2, ",", nlng, ",", ks, ",\n")
		#local l1 = nlng*(n1-1);
		#local l2 = nlng*(n2-1);
		#local xd = 1000*rand(st);
		#local yd = 1000*rand(st);
		#local i=0;
		#while (i<n1)
			#local j=0;
			#while (j<n2)
				#local tmpx = -l1/2 + i*nlng;
				#local tmpz = -l2/2 + j*nlng ;
          #local tmpy = 
            ht +
            (300*(f_marblep(tmpx*.1+xd,0,tmpz*.1+yd)*sin(10*pi*i/n1)))*nlng*0.01;
            #local tmp=vrotate(<tmpx,tmpy,tmpz>,0);
				#write(file, tmp.x, ",", tmp.y-7, ",", tmp.z, ", 0.0, 0.0, 0.0,\n")
				#set j=j+1;
			#end
			#set i=i+1;
		#end
		#fclose file
	#end

// Add constraints to the .cth file
	#macro WriteInitialDrapeau()
			WriteClothFile("drap.cth", 40*Precision, 40*Precision, 0.5/Precision, 100, 0)
	
	#end


// something to form some nice wrinkles
#declare stand=
union{
 plane{y,-10}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 sphere{0,.5+1.5*rand(r_stand) translate <-10+20*rand(r_stand),-10,-10+20*rand(r_stand)>}
 pigment{rgb 1}
}
// this one is to flatten a bit the wrinkles during the second simcloth call
#declare stand2=plane{y,-10 pigment{White}}

// cloth simulation
#if (use_simcloth)
#if (use_simcloth<2)
WriteInitialDrapeau()
#end
simcloth {
  environment stand
	gravity     -.5*y
	neighbors   1
	internal_collision off
	damping   0.9
	intervals   0.04
	iterations  400
	input       "drap.cth"
	output      "drap.cth"
	mesh_output "drap_s.msh"
	smooth_mesh on
	uv_mesh     on
}
simcloth {
  environment stand2
	gravity     -.5*y
	neighbors   1
	internal_collision off
	damping   0.9
	intervals   0.04
	iterations  200
	input       "drap.cth"
	output      "drap.cth"
	mesh_output "drap_s.msh"
	smooth_mesh on
	uv_mesh     on
}
#end
